function [SF, XScale, YScale] = SFdataXpt(ax)
% SFDataXPt - Return the conversion factor data units/pt. The conversion
% factor is determined from the figure. If the an axis is in log units, the
% corresponding conversion factor is log10(units)/pt. If the input argument
% is empty and there is no figure with axes, all ouput values are returned
% as empty.
%  SF - data units / points or log10(data units) / points
%  XScale - X-axis scale, 'linear' or 'log'
%  YScale - Y-axis sclae, 'linear' or 'log'
%  ax - Axes handle, defaults to gca

% This routine gets its information from a figure. A typical preamble
% before calling this routine is as follows.
%     axis([xmin, xmax, ymin, ymax]);   % Fix the limits
%     set (gca, 'XScale', 'log');  % For X log scale
%     set (gca, 'YScale', 'log');  % For Y log scale

% $Id: SFdataXpt.m,v 1.11 2018/02/22 21:24:59 pkabal Exp $

if (nargin == 0)
  if (~isempty(findobj(0, 'Type', 'axes')))
    ax = gca;
  else
    SF = [];
    XScale = [];
    YScale = [];
    return;
  end
end

% Get the axis size in points
Units = get(ax, 'Units');
set(ax, 'Units', 'points');
PosPt = get(ax, 'Position');
set(ax, 'Units', Units);  % Restore the axes units

XLim = get(ax, 'XLim');
YLim = get(ax, 'YLim');

XScale = get(ax, 'XScale');
if (strcmp(XScale, 'log'))
  XLim = log10(XLim);
end
YScale = get(ax, 'YScale');
if (strcmp(YScale, 'log'))
  YLim = log10(YLim);
end

SF = [diff(XLim) diff(YLim)] ./ PosPt(3:4);

end
